﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Arction.LightningChartUltimate;
using Arction.LightningChartUltimate.SeriesXY;

namespace IPETRONIK.Visual.Controls.Wpf.Test.Forms
{
	/// <summary>
	///     Code based on the DemoApp's "Heat map" sample
	/// </summary>
    public partial class FormIntensityLog : Form
    {
        internal static string LicenseKey = "<snipped>";

        /// <summary>
        ///     Constructor.
        /// </summary>
        public FormIntensityLog()
        {
            InitializeComponent();

            CreateChart();
            SetExampleData();
        }

        //Chart
        private LightningChartUltimate m_chart = null;

        //Intensity grid
        private IntensityGridSeries m_intensityGrid = null;



        /// <summary>
        /// Create chart.
        /// </summary>
        private void CreateChart()
        {
            //Create new chart
            m_chart = new LightningChartUltimate(LicenseKey);

            //Disable rendering, strongly recommended before updating chart properties
            m_chart.BeginUpdate();

            //Set active view
            m_chart.ActiveView = ActiveView.ViewXY;

            //Chart parent must be set
            m_chart.Parent = this; //splitContainer1.Panel1;

            //Fill parent area with chart
            m_chart.Dock = DockStyle.Fill;
            m_chart.BringToFront();
            
            //Setup x-axis
            m_chart.ViewXY.XAxes[0].ValueType = AxisValueType.Number;
            m_chart.ViewXY.XAxes[0].SetRange(0, 100);

            //Setup y-axis
            m_chart.ViewXY.YAxes[0].SetRange(0, 100);
            
            //Setup legend box
            m_chart.ViewXY.LegendBox.Layout = LegendBoxLayout.Vertical;

            //Enable multi-core processing 
            m_chart.RenderOptions.MultiCoreProcessing = MultiCoreProcessing.AllAvailableCores;

            //Allow chart rendering
            m_chart.EndUpdate();
            
            //base.RaiseChartsCreatedEvent();
        }
        
        /// <summary>
        /// Create series
        /// </summary>
        /// <param name="bitmap">Bitmap</param>
        private void CreateIntensitySeriesData(Bitmap bitmap)
        {
            //Disable rendering, strongly recommended before updating chart properties
            m_chart.BeginUpdate(); 

            //Create series once
            if (m_intensityGrid == null)
            {
                m_intensityGrid = new IntensityGridSeries(m_chart.ViewXY,  m_chart.ViewXY.XAxes[0], m_chart.ViewXY.YAxes[0]);
                m_intensityGrid.PixelRendering = true;
                m_intensityGrid.ContourLineType = ContourLineType.None;
                m_intensityGrid.Optimization = IntensitySeriesOptimization.DynamicData;
                m_intensityGrid.LegendBoxUnits = "°C";
                m_intensityGrid.LegendBoxValuesFormat = "0";
                m_intensityGrid.Title.Text = "Heat map";
                m_intensityGrid.MouseInteraction = false;
                m_chart.ViewXY.IntensityGridSeries.Add(m_intensityGrid); 
            }

            var options = new BitmapAntialiasOptions();

            if (m_intensityGrid.SetHeightDataFromBitmap(m_chart.ViewXY.XAxes[0].Minimum, m_chart.ViewXY.XAxes[0].Maximum,
                m_chart.ViewXY.YAxes[0].Minimum, m_chart.ViewXY.YAxes[0].Maximum, 0, 90,
                bitmap, options) == false)
            {
                MessageBox.Show("Intensity data creation failed. Too large source bitmap size for the GPU.");
            }

            //Allow chart rendering
            m_chart.EndUpdate(); 
        }
     
        /// <summary>
        /// Set data from file.
        /// </summary>
        private void SetExampleData()
        {
            //Load example data from resource stream 
            var bmp = new Bitmap("400x200_Rampe_SW.png");
            CreateIntensitySeriesData(bmp);
        }

        private void chkLogarithmic_CheckedChanged(object sender, EventArgs e)
        {
            var axis = m_chart.ViewXY.YAxes[0];

            axis.ScaleType = chkLogarithmic.Checked? ScaleType.Logarithmic : ScaleType.Linear;
        }
    }
}
